OG Image Generator - normattiva2md

Istruzioni per creare l'immagine OG

1. Imposta zoom del browser al 100%
2. Premi F11 per modalità fullscreen (o nascondi questa guida)
3. Fai screenshot 1200x630px della card blu
4. Salva come `og-image.png` in `site/assets/`

normattiva2md

# Converti le leggi italiane in testo semplice e strutturato per le intelligenze artificiali

Trasforma i contenuti di normattiva.it
in formato Markdown AI-ready
Open Source • Python 3.7+ • PyPI